@@ -233,7 +233,7 @@ NULL
 #'  the result before proceeding.
 #' @return
 #'  * `energy_calibrate()` returns a [GammaSpectrum-class] object.
-#'  * `has_energy()` returns a [`logical`] vector.
+#'  * `has_energy()` and `has_calibration()` return a [`logical`] vector.
 #' @example inst/examples/ex-energy.R
 #' @author N. Frerebeau
 #' @docType methods
@@ -255,6 +255,12 @@ setGeneric(
   def = function(object) standardGeneric("has_energy")
 )
 
+#' @rdname energy
+setGeneric(
+  name = "has_calibration",
+  def = function(object) standardGeneric("has_calibration")
+)
+
 # Baseline =====================================================================
 #' Baseline Estimation and Removal
 #'
@@ -387,8 +393,6 @@ setGeneric(
 #' @param doses A [`matrix`] or [`data.frame`] TODO.
 #' @param range_Ni,range_NiEi A length-two [`numeric`] vector giving the energy
 #'  range to integrate within (in keV).
-#' @param alpha A [`numeric`] value giving the cutoff value for confidence
-#'  intervals (see [IsoplotR::york()]).
 #' @param details A [`list`] of length-one vector specifying additional
 #'  informations about the instrument for which the curve is built.
 #' @param spectrum An optional [GammaSpectrum-class] or [GammaSpectra-class]
